@@ -181,7 +181,7 @@ class AudienceQuery(object):
         elif isinstance(raw_data, list):
 
             for el in raw_data:
-                parts.append(cls.parse(el, allowed_fields=allowed_fields))
+                parts.extend(cls.parse(el, allowed_fields=allowed_fields))
 
         else:
             raise InvalidQuery('Query needs to be a list or a dictionary.')
